import ldap3  # type: ignore
import base64
import json
import sys


def ldap_action(uid: str, config_json: dict) -> tuple[bool, list[str]] | None:

    server: ldap3.core.server.Server = ldap3.Server(
        config_json["ldap_host"],
        get_info=ldap3.ALL,
    )

    results: list[str] = []
    try:
        with ldap3.Connection(
            server,
            user=config_json["ldap_bind_dn"],
            password=config_json["ldap_bind_password"],
            auto_bind=True,
        ) as conn:

            conn.search(
                search_base=config_json["people_dn"],
                search_filter=f"(uid={uid})",
                attributes=["uid", "userSMIMECertificate"],
            )
            return conn.entries[0].entry_attributes_as_dict["userSMIMECertificate"][0]

    except Exception as e:
        print(f"Error creating user: {e}")
        return False, []

    return True, results


def main(uid: str, config_file: str = "config.json") -> None:

    with open(config_file, "r") as fid:
        config_json = json.load(fid)
    ldap_cert = ldap_action(uid=uid, config_json=config_json)
    ldap_pem = base64.b64decode(ldap_cert)  # type: ignore
    with open(f"Cert_{uid}.pem", "wb") as file:
        file.write(ldap_pem)


if __name__ == "__main__":
    uid: str = sys.argv[1]
    print(uid)
    main(uid)
