import ldap3  # type: ignore


def ldap_get_all_emails_for_uid(uid: str, config_json: dict) -> tuple[bool, list[str]]:

    server: ldap3.core.server.Server = ldap3.Server(
        config_json["ldap_host"], get_info=ldap3.ALL
    )

    results: list[str] = []
    try:
        with ldap3.Connection(
            server,
            user=config_json["ldap_bind_dn"],
            password=config_json["ldap_bind_password"],
            auto_bind=True,
        ) as conn:
            conn.search(
                search_base=config_json["people_dn"],
                search_filter=f"(uid={uid}#*)",
                attributes=["uid", "mail"],
            )

            for entry in conn.entries:
                results.append(entry.mail)

    except Exception as e:
        print(f"Error creating user: {e}")
        return False, []

    return True, results
