import ldap3  # type: ignore
import json
import sys
from functions.ldap_add_email_with_uid import ldap_add_email_with_uid
from functions.verify_certificate import verify_certificate

uid: str = sys.argv[1]
print(uid)

delete_legacy_entry: bool = True

with open("config.json", "r") as fid:
    config_json = json.load(fid)

with open(f"Cert_{uid}.pem", "r") as file:
    ldap_pem = file.read()

cert_data = ldap_pem.encode()

(
    certificate_status,
    certificate_error,
    certificate_emails,
    certificate_name,
    certificate_given_name,
    certificate_surname,
) = verify_certificate(
    cert_data=cert_data,
    ca_chain_path=config_json["ca_chain"],
    correct_organization=config_json["correct_organization"],
)

print("certificate_status: ", certificate_status)
print("certificate_error: ", certificate_error)
print("certificate_emails: ", certificate_emails)
print("certificate_name: ", certificate_name)
print("certificate_given_name: ", certificate_given_name)
print("certificate_surname: ", certificate_surname)


if (
    certificate_status
    and len(certificate_emails) > 0
    and len(certificate_name) > 0
    and len(certificate_given_name) > 0
    and len(certificate_surname) > 0
):
    for certificate_email in certificate_emails:
        print(certificate_email)
        ldap_add_email_with_uid(
            uid=uid,
            mail=certificate_email,
            givenName=certificate_given_name,
            sn=certificate_surname,
            cert=cert_data,
            config_json=config_json,
        )


if delete_legacy_entry:
    server: ldap3.core.server.Server = ldap3.Server(
        config_json["ldap_host"], get_info=ldap3.ALL
    )
    try:
        with ldap3.Connection(
            server,
            user=config_json["ldap_bind_dn"],
            password=config_json["ldap_bind_password"],
            auto_bind=True,
        ) as conn:
            conn.search(
                search_base=config_json["people_dn"],
                search_filter=f"(uid={uid})",
                attributes=["uid"],
            )
            entries_to_delete = []
            for entry in conn.entries:
                entries_to_delete.append(entry.entry_dn)
            for entry in entries_to_delete:
                conn.delete(entry)

    except Exception as e:
        print(f"Error delete user: {e}")
